@@ -30,7 +30,7 @@ class HOpt:
         xgb1.fit(self.X_train, self.Y_train)
         y_pred = xgb1.predict(self.X_val)
         acc = mean_squared_error(self.Y_val, y_pred)
-        return {'loss': acc, 'status': STATUS_OK}
+        return {'loss': acc, 'status': STATUS_OK, 'model': xgb1}
 
     def optimize(self, evals=50):
         trials = Trials()
